"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prismjs_1 = __importDefault(require("prismjs"));
const lodash_1 = __importDefault(require("lodash"));
const loadPrismLanguage_1 = require("./loadPrismLanguage");
const directives_1 = require("./directives");
const unsupportedLanguages = new Set();
function highlightCode(language, code, lineNumbersHighlight = [], noInlineHighlight = false) {
    // (Try to) load languages on demand.
    if (!prismjs_1.default.languages[language]) {
        try {
            loadPrismLanguage_1.loadPrismLanguage(language);
        }
        catch (e) {
            // Language wasn't loaded so let's bail.
            let message = null;
            switch (language) {
                case "none":
                    return code; // Don't escape if set to none.
                case "text":
                    message = noInlineHighlight
                        ? "code block language not specified in markdown."
                        : "code block or inline code language not specified in markdown.";
                    break;
                default:
                    message = `unable to find prism language '${language}' for highlighting.`;
            }
            const lang = language.toLowerCase();
            if (!unsupportedLanguages.has(lang)) {
                console.warn(message, "applying generic code block");
                unsupportedLanguages.add(lang);
            }
            return lodash_1.default.escape(code);
        }
    }
    const grammar = prismjs_1.default.languages[language];
    const highlighted = prismjs_1.default.highlight(code, grammar, language);
    const codeSplits = directives_1.handleDirectives(highlighted, lineNumbersHighlight);
    let finalCode = "";
    const lastIdx = codeSplits.length - 1;
    // Don't add back the new line character after highlighted lines
    // as they need to be display: block and full-width.
    codeSplits.forEach((split, idx) => {
        finalCode += split.highlight
            ? split.code
            : `${split.code}${idx === lastIdx ? "" : "\n"}`;
    });
    return finalCode;
}
exports.highlightCode = highlightCode;
//# sourceMappingURL=highlightCode.js.map