"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prismjs_1 = __importDefault(require("prismjs"));
const components_1 = __importDefault(require("prismjs/components"));
const lodash_1 = __importDefault(require("lodash"));
function getBaseLanguageName(nameOrAlias, components = components_1.default) {
    if (components.languages[nameOrAlias]) {
        return nameOrAlias;
    }
    return lodash_1.default.find(components.languages, value => {
        const { alias } = value;
        if (!alias) {
            return false;
        }
        return lodash_1.default.isArray(alias)
            ? alias.includes(nameOrAlias)
            : alias === nameOrAlias;
    });
}
function loadPrismLanguage(language) {
    const baseLanguage = getBaseLanguageName(language);
    if (!baseLanguage) {
        throw new Error(`Prism doesn't support language '${language}'.`);
    }
    if (prismjs_1.default.languages[baseLanguage]) {
        // Don't load already loaded language
        return;
    }
    const languageData = components_1.default.languages[baseLanguage];
    if (languageData.option === "default") {
        // Default language has already been loaded by Prism
        return;
    }
    if (languageData.require) {
        // Load the required language first
        if (Array.isArray(languageData.require)) {
            languageData.require.forEach(loadPrismLanguage);
        }
        else {
            loadPrismLanguage(languageData.require);
        }
    }
    require(`prismjs/components/prism-${baseLanguage}.js`);
}
exports.loadPrismLanguage = loadPrismLanguage;
//# sourceMappingURL=loadPrismLanguage.js.map